#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import json
import re
from flatten_json import flatten
from moz_sql_parser import parse

def remove_comments(sql):
    ## remove the /* */ comments
    sql2 = re.sub(r"/\*[^*]*\*+(?:[^*/][^*]*\*+)*/", "", sql)

    # remove whole line -- and # comments
    lines = [line for line in sql2.splitlines() if not re.match("^\s*(--|#)", line)]
    # remove trailing -- and # comments
    return " ".join([re.split("--|#", line)[0] for line in lines]).strip()
    
def extract_tables_from_select(sql):
    """extract tables and views from a select statement"""
    pattern = "from(_\d+)?(.*join)?$"
    sql_dict = flatten(parse(sql))
    return [value for key, value in sql_dict.items() if re.search(pattern, key)]



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sqlu",
    version="0.1.1",
    author="Matteo Redaelli",
    author_email="matteo.redaelli@gmail.com",
    description="sqlu is a simple utility for transforming or extracting info from sql statements",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/matteo.redaelli/sqlu",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=['flatten_json', 'moz_sql_parser'],
    python_requires='>=3.6',
)
